from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_Module = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AST50147-xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AST50147-xx'}), 'ref_prefix':'U', 'fplist':['RF_Module:Astrocast_AST50147-00'], 'footprint':'RF_Module:Astrocast_AST50147-00', 'keywords':'RF module Astrocast radio Astronode ', 'description':'', 'datasheet':'https://docs.astrocast.com/dl/0532-DOC-M2M-ASTRO-Astronode_S-Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nAST50147-xx\n\nRF module Astrocast radio Astronode ', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='ANTN_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='38',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='EVENT_NOTIF',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='ANTN_USE',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='WAKEUP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAMR21G18-MR210UA_NoRFPads', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAMR21G18-MR210UA_NoRFPads'}), 'ref_prefix':'U', 'fplist':['RF_Module:Atmel_ATSAMR21G18-MR210UA_NoRFPads'], 'footprint':'RF_Module:Atmel_ATSAMR21G18-MR210UA_NoRFPads', 'keywords':'Wireless Zigbee 802.15.4 ATSAMR21G18 AT45DB041E TECC508A', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/atmel-42475-atsamr21g18-mr210ua_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nATSAMR21G18-MR210UA_NoRFPads\n\nWireless Zigbee 802.15.4 ATSAMR21G18 AT45DB041E TECC508A', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA28',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='ATECC508_GPIO',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA19',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AX-SIP-SFEU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AX-SIP-SFEU'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:OnSemi_SIP-38-6EP-9x7mm_P0.65mm_EP1.2x1.2mm'], 'footprint':'Package_DFN_QFN:OnSemi_SIP-38-6EP-9x7mm_P0.65mm_EP1.2x1.2mm', 'keywords':'Sigfox SIP 868Mhz', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/AX-SIP-SFEU-D.PDF', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nAX-SIP-SFEU\n\nSigfox SIP 868Mhz', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO11/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO10/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO8/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO7/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO6/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO5/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO4/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CPULED',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='RADIOLED',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='GPIO9/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='UART_TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='UART_RX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RX_LED',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='TX_LED',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='NC24',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GPIO0/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GPIO1/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GPIO2/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='GPIO3/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GPIO12/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GPIO13/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='GPIO14/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='38',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AX-SIP-SFEU-API', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AX-SIP-SFEU-API'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:OnSemi_SIP-38-6EP-9x7mm_P0.65mm_EP1.2x1.2mm'], 'footprint':'Package_DFN_QFN:OnSemi_SIP-38-6EP-9x7mm_P0.65mm_EP1.2x1.2mm', 'keywords':'Sigfox SIP 868Mhz', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/AX-SIP-SFEU-D.PDF', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nAX-SIP-SFEU-API\n\nSigfox SIP 868Mhz', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO11/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO10/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO8/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO7/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO6/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO5/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO4/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CPULED/PB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='RADIOLED/PB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='GPIO9/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='UART_TX/PB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='UART_RX/PB5',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DBG_DATA/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DBG_CLK/PB7',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DBG_EN',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GPIO0/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GPIO1/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GPIO2/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='GPIO3/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GPIO12/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GPIO13/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='GPIO14/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='38',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Ai-Thinker-Ra-01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Ai-Thinker-Ra-01'}), 'ref_prefix':'U', 'fplist':['RF_Module:Ai-Thinker-Ra-01-LoRa'], 'footprint':'RF_Module:Ai-Thinker-Ra-01-LoRa', 'keywords':'Ra-01 LoRa', 'description':'', 'datasheet':'http://wiki.ai-thinker.com/_media/lora/docs/c047ps01a1_ra-01_product_specification_v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nAi-Thinker-Ra-01\n\nRa-01 LoRa', 'pins':[
            Pin(num='1',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{NSS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Ai-Thinker-Ra-02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Ai-Thinker-Ra-02'}), 'ref_prefix':'U', 'fplist':['RF_Module:Ai-Thinker-Ra-01-LoRa'], 'footprint':'RF_Module:Ai-Thinker-Ra-01-LoRa', 'keywords':'Ra-02 LoRa', 'description':'', 'datasheet':'http://wiki.ai-thinker.com/_media/lora/docs/c048ps01a1_ra-02_product_specification_v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nAi-Thinker-Ra-02\n\nRa-02 LoRa', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{NSS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CMWX1ZZABZ-078', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CMWX1ZZABZ-078'}), 'ref_prefix':'U', 'fplist':['RF_Module:CMWX1ZZABZ'], 'footprint':'RF_Module:CMWX1ZZABZ', 'keywords':'iot lora sigfox', 'description':'', 'datasheet':'https://wireless.murata.com/RFM/data/type_abz.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nCMWX1ZZABZ-078\n\niot lora sigfox', 'pins':[
            Pin(num='1',name='PA12/USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SX1276_DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DBG_SX1276_DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DBG_SX1276_DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DBG_SX1276_DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB15/SPI2_MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB14/SPI2_MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB13/SPI2_SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB12/SPI2_NSS',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA10/USART1_RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/USART1_TX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA11/USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8/MCO',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5/ADC5/DAC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA4/ADC4/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA3/ADC3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2/ADC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='DBG_CRF1',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DBG_CRF3',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='DGB_CRF2',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='~{STSAFE_RST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PA0/WKUP1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{MCU_RST}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PB8/I2C1_SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB9/I2C1_SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2/LPTIM1_OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB7/LPTIM1_IN2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB6/LPTIM1_ETR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PB5/LPTIM1_IN1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA13/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA14/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='PH1/OSC_OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH0/OSC_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='TCXO_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='VDD_TCXO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VDD_MCU',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VDD_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DBG_SX1276_DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DBG_SX1276_DI03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D52MxxM8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D52MxxM8'}), 'ref_prefix':'U', 'fplist':['RF_Module:Garmin_M8-35_9.8x14.0mm_Layout6x6_P1.5mm'], 'footprint':'RF_Module:Garmin_M8-35_9.8x14.0mm_Layout6x6_P1.5mm', 'keywords':'RF Radio ANT Bluetooth BLE D52 nRF52 Garmin Canada Dynastream Nordic', 'description':'', 'datasheet':'https://www.thisisant.com/assets/resources/D00001687_D52_Module_Datasheet.v.2.3_(Garmin).pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nD52MxxM8\n\nRF Radio ANT Bluetooth BLE D52 nRF52 Garmin Canada Dynastream Nordic', 'pins':[
            Pin(num='A2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P012',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P015',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P020',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='NFC1/P009',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='NFC2/P010',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P016',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='P008',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P014',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='P013',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='P022',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P018',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='P024',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P006',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AIN3/P005',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='AIN1/P003',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='AIN2/P004',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AIN0/P002',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P021/RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P025',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='AIN7/P031',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='AIN6/P030',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='AIN5/P029',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='AIN4/P028',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P011',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DWM1000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DWM1000'}), 'ref_prefix':'DWM', 'fplist':['RF_Module:DWM1000'], 'footprint':'RF_Module:DWM1000', 'keywords':'Decawave Qorvo UWB', 'description':'', 'datasheet':'https://www.decawave.com/sites/default/files/resources/dwm1000-datasheet-v1.3.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nDWM1000\n\nDecawave Qorvo UWB', 'pins':[
            Pin(num='1',name='EXTON',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GPIO5/EXTTXE/SPIPOL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO4/EXTPA',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO3/TXLED',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO2/RXLED',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO1/SFDLED',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO0/RXOKLED',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='~{SPICS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SPIMOSI',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SPIMISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='WAKEUP',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SPICLK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='IRQ/GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{RST}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDAON',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDD3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GPIO6/EXTRXE/SPIHA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DWM1001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DWM1001'}), 'ref_prefix':'U', 'fplist':['RF_Module:DecaWave_DWM1001'], 'footprint':'RF_Module:DecaWave_DWM1001', 'keywords':'DWM1000  DecaWave RF ranging UWB', 'description':'', 'datasheet':'https://www.decawave.com/sites/default/files/dwm1001_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nDWM1001\n\nDWM1000  DecaWave RF ranging UWB', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO_30',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GPIO_27',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='I2C_SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='I2C_SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='GPIO_23',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GPIO_13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='UART_RX',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='READY',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SWD_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='UART_TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='GPIO_1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPIO_15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GPIO_8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SPIS_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SPIS_MOSI',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='SPIS_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='~{SPIS_CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SWD_DIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GPIO_3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GPIO_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='BT_WAKE_UP',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GPIO_10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPIO_9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPIO_12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPIO_14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO_22',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GPIO_31',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'E18-MS1-PCB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'E18-MS1-PCB'}), 'ref_prefix':'U', 'fplist':['RF_Module:E18-MS1-PCB'], 'footprint':'RF_Module:E18-MS1-PCB', 'keywords':'Zigbee, RF, 802.15.4', 'description':'', 'datasheet':'http://www.cdebyte.com/en/downpdf.aspx?id=122', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nE18-MS1-PCB\n\nZigbee, RF, 802.15.4', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'E73-2G4M04S-52832', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'E73-2G4M04S-52832'}), 'ref_prefix':'U', 'fplist':['RF_Module:E73-2G4M04S'], 'footprint':'RF_Module:E73-2G4M04S', 'keywords':'BLE5, BLE, nRF52832', 'description':'', 'datasheet':'http://www.cdebyte.com/en/downpdf.aspx?id=243', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nE73-2G4M04S-52832\n\nBLE5, BLE, nRF52832', 'pins':[
            Pin(num='0',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='AIN6/P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AIN7/P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DEC4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='DEC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AIN0/P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AIN1/P0.03',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AIN2/P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='AIN3/P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NFC1/P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NFC2/P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DEC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SWO/P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.21/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DEC3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AIN4/P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AIN5/P0.29',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP-07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP-07'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP-07'], 'footprint':'RF_Module:ESP-07', 'keywords':'802.11 Wi-Fi', 'description':'', 'datasheet':'http://wiki.ai-thinker.com/_media/esp8266/esp8266_series_modules_user_manual_v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP-07\n\n802.11 Wi-Fi', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GPIO15',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO3/RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO1/TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GPIO16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPIO14',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPIO13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP-12E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP-12E'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP-12E'], 'footprint':'RF_Module:ESP-12E', 'keywords':'802.11 Wi-Fi', 'description':'', 'datasheet':'http://wiki.ai-thinker.com/_media/esp8266/esp8266_series_modules_user_manual_v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP-12E\n\n802.11 Wi-Fi', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GPIO15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GPIO3/RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO1/TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GPIO16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPIO14',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPIO13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CS0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP-WROOM-02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP-WROOM-02'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP-WROOM-02'], 'footprint':'RF_Module:ESP-WROOM-02', 'keywords':'RF Radio ESP Espressif', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/0c-esp-wroom-02_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP-WROOM-02\n\nRF Radio ESP Espressif', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TOUT',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-C3-WROOM-02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-C3-WROOM-02'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-C3-WROOM-02'], 'footprint':'RF_Module:ESP32-C3-WROOM-02', 'keywords':'esp32 espressif WiFi Bluetooth LE', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-c3-wroom-02_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-C3-WROOM-02\n\nesp32 espressif WiFi Bluetooth LE', 'pins':[
            Pin(num='1',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO20/RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO21/TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO9',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-C3-WROOM-02U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-C3-WROOM-02U'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-C3-WROOM-02U'], 'footprint':'RF_Module:ESP32-C3-WROOM-02U', 'keywords':'esp32 espressif WiFi Bluetooth LE', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-c3-wroom-02_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-C3-WROOM-02U\n\nesp32 espressif WiFi Bluetooth LE', 'pins':[
            Pin(num='1',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO20/RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO21/TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO9',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-S2-WROVER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-S2-WROVER'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-S2-WROVER'], 'footprint':'RF_Module:ESP32-S2-WROVER', 'keywords':'RF Radio ESP ESP32 Espressif onboard PCB antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-s2-wroom_esp32-s2-wroom-i_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-S2-WROVER\n\nRF Radio ESP ESP32 Espressif onboard PCB antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='IO33',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO34',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO35',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO00',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO36',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO37',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO38',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='IO39',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO40',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO41',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO42',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO45',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO01',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO46',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO02',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO03',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO04',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO05',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-S3-MINI-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-S3-MINI-1'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-S2-MINI-1'], 'footprint':'RF_Module:ESP32-S2-MINI-1', 'keywords':'RF Radio BT ESP ESP32-S3 Espressif', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-s3-mini-1_mini-1u_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-S3-MINI-1\n\nRF Radio BT ESP ESP32-S3 Espressif', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO11',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO20',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO47',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO33',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO34',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='IO48',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO35',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO36',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='IO37',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO38',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO39',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO40',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO41',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO42',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO45',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='IO46',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-S3-WROOM-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-S3-WROOM-1'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-S3-WROOM-1'], 'footprint':'RF_Module:ESP32-S3-WROOM-1', 'keywords':'RF Radio BT ESP ESP32-S3 Espressif onboard PCB antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-s3-wroom-1_wroom-1u_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-S3-WROOM-1\n\nRF Radio BT ESP ESP32-S3 Espressif onboard PCB antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO20',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO46',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO11',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO47',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO48',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO45',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO35',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO36',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO37',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO38',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO39',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='IO40',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO41',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO42',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO16',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-S3-WROOM-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-S3-WROOM-2'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-S3-WROOM-2'], 'footprint':'RF_Module:ESP32-S3-WROOM-2', 'keywords':'Bluetooth WiFi Wi-Fi ESP WROOM', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-s3-wroom-2_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-S3-WROOM-2\n\nBluetooth WiFi Wi-Fi ESP WROOM', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='USB_D-/IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='USB_D+/IO20',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO46',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO11',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO47',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO48',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO45',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='IO38',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='MTCK/IO39',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='MTDO/IO40',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='MTDI/IO41',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='MTMS/IO42',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RXD0/IO44',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TXD0/IO43',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO16',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-WROOM-32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-WROOM-32'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-WROOM-32'], 'footprint':'RF_Module:ESP32-WROOM-32', 'keywords':'RF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-wroom-32_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-WROOM-32\n\nRF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO25',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SHD/SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SWP/SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCS/CMD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SCK/CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SDO/SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SDI/SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RXD0/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TXD0/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO22',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO23',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SENSOR_VP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSOR_VN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO34',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO35',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO32',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO33',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-WROOM-32E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-WROOM-32E'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-WROOM-32D'], 'footprint':'RF_Module:ESP32-WROOM-32D', 'keywords':'RF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-wroom-32e_esp32-wroom-32ue_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-WROOM-32E\n\nRF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO25',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RXD0/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TXD0/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO22',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO23',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SENSOR_VP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSOR_VN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO34',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO35',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO32',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO33',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-WROOM-32E-R2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-WROOM-32E-R2'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-WROOM-32D'], 'footprint':'RF_Module:ESP32-WROOM-32D', 'keywords':'RF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-wroom-32e_esp32-wroom-32ue_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-WROOM-32E-R2\n\nRF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO25',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RXD0/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TXD0/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO22',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO23',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SENSOR_VP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSOR_VN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO34',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO35',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO32',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO33',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-WROOM-32U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-WROOM-32U'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-WROOM-32U'], 'footprint':'RF_Module:ESP32-WROOM-32U', 'keywords':'RF Radio BT ESP ESP32 Espressif external U.FL antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-wroom-32d_esp32-wroom-32u_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-WROOM-32U\n\nRF Radio BT ESP ESP32 Espressif external U.FL antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO25',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SHD/SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SWP/SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCS/CMD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SCK/CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SDO/SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SDI/SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RXD0/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TXD0/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO22',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO23',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SENSOR_VP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSOR_VN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO34',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO35',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO32',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO33',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HT-CT62', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HT-CT62'}), 'ref_prefix':'U', 'fplist':['RF_Module:Heltec_HT-CT62'], 'footprint':'RF_Module:Heltec_HT-CT62', 'keywords':'LoRa WiFi ESP32 SX1262', 'description':'', 'datasheet':'https://resource.heltec.cn/download/HT-CT62/HT-CT62(Rev1.1).pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nHT-CT62\n\nLoRa WiFi ESP32 SX1262', 'pins':[
            Pin(num='1',name='2.4G_Ant',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GPIO18_DN',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO19_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPIO20_RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GPIO21_TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='LoRa_Ant',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPIO6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GPIO1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDBT42Q-512K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDBT42Q-512K'}), 'ref_prefix':'U', 'fplist':['RF_Module:Raytac_MDBT42Q'], 'footprint':'RF_Module:Raytac_MDBT42Q', 'keywords':'MCU ARM BLE ANT 2.4GHz 802.15.4 MDBT42Q', 'description':'', 'datasheet':'https://www.raytac.com/download/index.php?index_id=27', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMDBT42Q-512K\n\nMCU ARM BLE ANT 2.4GHz 802.15.4 MDBT42Q', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DCC',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P0.00/XL1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.01/XL2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AIN0/P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AIN1/P0.03',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AIN2/P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AIN3/P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='NFC1/P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='NFC2/P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TRACEDATA3/P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TRACEDATA2/P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TRACEDATA1/P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TRACEDATA0/P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TRACECLK/P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.21/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AIN4/P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AIN5/P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AIN6/P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AIN7/P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DEC4',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDBT50Q-1MV2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDBT50Q-1MV2'}), 'ref_prefix':'U', 'fplist':['RF_Module:Raytac_MDBT50Q'], 'footprint':'RF_Module:Raytac_MDBT50Q', 'keywords':'BLE ANT ZigBee Thread 802.15.4 nRF52840 nordic MDBT50Q', 'description':'', 'datasheet':'https://www.raytac.com/download/index.php?index_id=43', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMDBT50Q-1MV2\n\nBLE ANT ZigBee Thread 802.15.4 nRF52840 nordic MDBT50Q', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.00',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P0.01',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1.08',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P1.09',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.10',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDH',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='DCCH',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.11',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P1.00',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.12',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P1.02',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P1.04',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P1.06',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P1.07',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.05',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.03',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.01',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1.14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P1.15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDBT50Q-512K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDBT50Q-512K'}), 'ref_prefix':'U', 'fplist':['RF_Module:Raytac_MDBT50Q'], 'footprint':'RF_Module:Raytac_MDBT50Q', 'keywords':'MCU, ARM, BLE, ANT, 2.4GHz, 802.15.4 MDBT50Q', 'description':'', 'datasheet':'https://www.raytac.com/download/index.php?index_id=46', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMDBT50Q-512K\n\nMCU, ARM, BLE, ANT, 2.4GHz, 802.15.4 MDBT50Q', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.00',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P0.01',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1.08',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P1.09',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDH',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.19',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P1.00',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P1.02',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P1.04',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P1.06',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P1.07',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='P1.05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='P1.01',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1.03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MM002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MM002'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'IOT LoRa SIGFOX', 'description':'', 'datasheet':'http://www.nemeus.fr/resources/uploads/2015/04/MM002-xx-EU_datasheet_v0.11.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMM002\n\nIOT LoRa SIGFOX', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA15-IO/JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA14-IO/JTCK/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA13-IO/JTMS/SWDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA12-IO/UART1-RTS/USB-DP',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11-IO/UART1-CTS/USB-DM',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='ANT',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA7-IO/SPI-MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PA5-IO/SPI-SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA6-IO/SPI-MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA4-IO/SPI-NSS',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA3-IO/ADC/UART2-RX',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2-IO/ADC/UART2-TX',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0-IO/ADC/UART2-CTS/WKUP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1-IO/ADC/UART2-RTS',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB9-IO/I2C-SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB8-IO/I2C-SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='BOOT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PB7-IO/UART1-RX',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6-IO/UART1-TX',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4-IO/NJTRST',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PB3-IO/JTDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Particle_P1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Particle_P1'}), 'ref_prefix':'U', 'fplist':['RF_Module:Particle_P1'], 'footprint':'RF_Module:Particle_P1', 'keywords':'Wi-Fi module', 'description':'', 'datasheet':'https://docs.particle.io/datasheets/p1-datasheet/', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nParticle_P1\n\nWi-Fi module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='WL_JTAG_TDI',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='WL_JTAG_TCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='WL_JTAG_~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='WL_JTAG_TMS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VBAT_WL',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='WL_JTAG_TDO',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='MICRO_SPI1_MISO/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='MICRO_SPI1_SCK/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='MICRO_SPI1_MOSI/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='MICRO_SPI1_SS/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD_3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VDD_3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='MICRO_UART2_RTS/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT_WL',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='MICRO_UART2_CTS/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='MICRO_UART2_RXD/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='MICRO_UART2_TXD/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TESTMODE',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='MICRO_~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='MICRO_I2C1_SCL/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='MICRO_I2C1_SDA/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VBAT_MICRO',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='MICRO_GPIO_1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='MICRO_GPIO_2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='MICRO_GPIO_3/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='MICRO_GPIO_5/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='MICRO_GPIO_6/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='MICRO_GPIO_7/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='MICRO_GPIO_8/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='MICRO_GPIO_9/PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='MICRO_GPIO_12/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='MICRO_GPIO_13/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDIO_3V3_WL',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='MICRO_GPIO_14/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='MICRO_JTAG_~{TRST}/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='MICRO_JTAG_TDO/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='MICRO_JTAG_TDI/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='MICRO_JTAG_TMS/PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='MICRO_JTAG_TCK/PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='BTCX_STATUS',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='BTCX_RF_ACTIVE',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='BTCX_TXCONF',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='WL_SLEEP_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='MICRO_UART1_RTS/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='MICRO_UART1_CTS/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='MICRO_UART1_RXD/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='MICRO_UART1_TXD/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='68',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='WL_REG_ON',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PAD1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='75',name='PAD2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK4200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK4200'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK4200'], 'footprint':'RF_Module:RAK4200', 'keywords':'IoT, LoRa, LoRaWAN, RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK4200/Hardware-Specification/RAK4200_Module_Specifications_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK4200\n\nIoT, LoRa, LoRaWAN, RF', 'pins':[
            Pin(num='1',name='PA3/UART2_RX',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='I2C_SDA/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PA5/SPI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6/SPI_MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7/SPI_MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{MCU_NRESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA2/UART2_TX',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA1/UART2_DE',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA9/UART1_TX',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA10/UART1_RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA12/UART1_DE',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA14/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='I2C_SCL/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-HF-EU868', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-HF-EU868'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-HF-EU868\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PB3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB8',func=pin_types.BIDIR),
            Pin(num='19',name='PB9',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PA8',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PB4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-LF-EU433', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-LF-EU433'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-LF-EU433\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PA3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB6',func=pin_types.BIDIR),
            Pin(num='19',name='PB7',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PB13',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PA11',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM69HW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM69HW'}), 'ref_prefix':'U', 'fplist':['RF_Module:HOPERF_RFM69HW'], 'footprint':'RF_Module:HOPERF_RFM69HW', 'keywords':'Radio ISM Transceiver Module AES', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcbb56f1fd7.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM69HW\n\nRadio ISM Transceiver Module AES', 'pins':[
            Pin(num='1',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ANA',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM95W-868S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM95W-868S2'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcbea20e9ef.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM95W-868S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB5MMG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB5MMG'}), 'ref_prefix':'U', 'fplist':['RF_Module:ST-SiP-LGA-86-11x7.3mm'], 'footprint':'RF_Module:ST-SiP-LGA-86-11x7.3mm', 'keywords':'bluetooth bluetooth5 bluetooth5.0 802.15.4 zigbee module stm32 rf ARM Cortex-M3 Cortex-M0+', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb5mmg.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nSTM32WB5MMG\n\nbluetooth bluetooth5 bluetooth5.0 802.15.4 zigbee module stm32 rf ARM Cortex-M3 Cortex-M0+', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH3-BOOT0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='ANT_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='RF_OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='ANT_NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='86',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TD1205', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TD1205'}), 'ref_prefix':'U', 'fplist':['RF_Module:TD1205'], 'footprint':'RF_Module:TD1205', 'keywords':'IOT SIGFOX GPS', 'description':'', 'datasheet':'https://github.com/Telecom-Design/Documentation_TD_RF_Module/blob/master/TD1205%20Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nTD1205\n\nIOT SIGFOX GPS', 'pins':[
            Pin(num='1',name='BAT-',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='BAT+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UART-TX',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='UART-RX',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DB2-SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DB3-SWCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TD1208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TD1208'}), 'ref_prefix':'U', 'fplist':['RF_Module:TD1208'], 'footprint':'RF_Module:TD1208', 'keywords':'IOT SIGFOX', 'description':'', 'datasheet':'https://github.com/Telecom-Design/Documentation_TD_RF_Module/blob/master/TD1208%20Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nTD1208\n\nIOT SIGFOX', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='USR2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='USR3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USR0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='USR1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='UART-TX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UART-RX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='ADC0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TIM2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='RF_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='RF',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RF_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Reserved',func=pin_types.UNSPEC,unit=1),
            Pin(num='4',name='USR4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DB3-SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DB2-SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TR-52DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR-52DA'}), 'ref_prefix':'U', 'fplist':['RF_Module:IQRF_TRx2DA_KON-SIM-01'], 'footprint':'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'keywords':'IQRF common transceiver, PCB antenna, FSK modulation', 'description':'', 'datasheet':'https://iqrf.org/weben/downloads.php?id=213', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nTR-52DA\n\nIQRF common transceiver, PCB antenna, FSK modulation', 'pins':[
            Pin(num='C1',name='RA0/AN0/C12IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RC2/VOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='RA5/RB4/RC6/AN4/AN11/TX/~{SS}/C2OUT/CCP3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='RC5/RC7/RX/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'iM880A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'iM880A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'IOT LoRa', 'description':'', 'datasheet':'http://www.wireless-solutions.de/images/stories/downloads/Radio%20Modules/iM880A/General_Information/iM880A_Datasheet_V1_1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\niM880A\n\nIOT LoRa', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P7-IO/SPI-MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P8-IO/SPI-MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P9-IO/SPI-CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P10-IO/SPI-NSS',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RxD-IO/UART-RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TxD-IO/UART-TX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1-IO/JTCK/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P11-IO',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P12-IO/I2C-SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='P13-IO/I2C-SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P14-IO/ADC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P15-IO/WKUP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='BOOT',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='P17-IO/ADC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2-IO/JTMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='RF',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P3-IO/JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4-IO/JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P5-IO/UART-CTS',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P6-IO/UART-RTS',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CMWX1ZZABZ-091', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CMWX1ZZABZ-091'}), 'ref_prefix':'U', 'fplist':['RF_Module:CMWX1ZZABZ', 'RF_Module:CMWX1ZZABZ'], 'footprint':'RF_Module:CMWX1ZZABZ', 'keywords':'iot lora sigfox', 'description':'', 'datasheet':'https://wireless.murata.com/RFM/data/type_abz.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nCMWX1ZZABZ-091\n\niot lora sigfox', 'pins':[
            Pin(num='1',name='PA12/USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SX1276_DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DBG_SX1276_DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DBG_SX1276_DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DBG_SX1276_DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB15/SPI2_MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB14/SPI2_MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB13/SPI2_SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB12/SPI2_NSS',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA10/USART1_RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/USART1_TX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA11/USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8/MCO',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5/ADC5/DAC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA4/ADC4/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA3/ADC3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2/ADC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='DBG_CRF1',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DBG_CRF3',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='DGB_CRF2',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='~{STSAFE_RST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PA0/WKUP1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{MCU_RST}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PB8/I2C1_SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB9/I2C1_SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2/LPTIM1_OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB7/LPTIM1_IN2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB6/LPTIM1_ETR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PB5/LPTIM1_IN1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA13/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA14/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='PH1/OSC_OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH0/OSC_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='TCXO_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='VDD_TCXO',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VDD_MCU',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VDD_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DBG_SX1276_DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DBG_SX1276_DI03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DCTR-52DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DCTR-52DA'}), 'ref_prefix':'U', 'fplist':['RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01'], 'footprint':'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'keywords':'IQRF data controlled transceiver, PCB antenna, FSK modulation', 'description':'', 'datasheet':'https://iqrf.org/weben/downloads.php?id=213', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nDCTR-52DA\n\nIQRF data controlled transceiver, PCB antenna, FSK modulation', 'pins':[
            Pin(num='C1',name='RA0/AN0/C12IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RC2/VOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='RA5/RB4/RC6/AN4/AN11/TX/~{SS}/C2OUT/CCP3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='RC5/RC7/RX/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DCTR-52DAT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DCTR-52DAT'}), 'ref_prefix':'U', 'fplist':['RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01'], 'footprint':'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'keywords':'IQRF data controlled transceiver, PCB antenna, thermometer, FSK modulation', 'description':'', 'datasheet':'https://iqrf.org/weben/downloads.php?id=213', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nDCTR-52DAT\n\nIQRF data controlled transceiver, PCB antenna, thermometer, FSK modulation', 'pins':[
            Pin(num='C1',name='RA0/AN0/C12IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RC2/VOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='RA5/RB4/RC6/AN4/AN11/TX/~{SS}/C2OUT/CCP3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='RC5/RC7/RX/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DWM3000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DWM3000'}), 'ref_prefix':'DWM', 'fplist':['RF_Module:DWM1000', 'RF_Module:DWM1000'], 'footprint':'RF_Module:DWM1000', 'keywords':'DWM3000 Decawave Qorvo RF ranging UWB', 'description':'', 'datasheet':'https://www.qorvo.com/products/d/da008334', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nDWM3000\n\nDWM3000 Decawave Qorvo RF ranging UWB', 'pins':[
            Pin(num='1',name='EXTON',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GPIO5/EXTTXE/SPIPOL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO4/EXTPA',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO3/TXLED',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO2/RXLED',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO1/SFDLED',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO0/RXOKLED',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='~{SPICS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SPIMOSI',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SPIMISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='WAKEUP',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SPICLK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='IRQ/GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{RST}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDAON',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDD3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GPIO6/EXTRXE/SPIHA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'E73-2G4M04S-52810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'E73-2G4M04S-52810'}), 'ref_prefix':'U', 'fplist':['RF_Module:E73-2G4M04S', 'RF_Module:E73-2G4M04S'], 'footprint':'RF_Module:E73-2G4M04S', 'keywords':'BLE5, BLE, nRF52810', 'description':'', 'datasheet':'http://www.cdebyte.com/en/downpdf.aspx?id=243', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nE73-2G4M04S-52810\n\nBLE5, BLE, nRF52810', 'pins':[
            Pin(num='0',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='AIN6/P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AIN7/P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DEC4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='DEC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AIN0/P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AIN1/P0.03',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AIN2/P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='AIN3/P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NFC1/P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NFC2/P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DEC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SWO/P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.21/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DEC3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AIN4/P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AIN5/P0.29',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP-12F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP-12F'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP-12E', 'RF_Module:ESP-12E'], 'footprint':'RF_Module:ESP-12E', 'keywords':'802.11 Wi-Fi', 'description':'', 'datasheet':'http://wiki.ai-thinker.com/_media/esp8266/esp8266_series_modules_user_manual_v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP-12F\n\n802.11 Wi-Fi', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GPIO15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GPIO3/RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO1/TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GPIO16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPIO14',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPIO13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CS0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-S2-WROVER-I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-S2-WROVER-I'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-S2-WROVER', 'RF_Module:ESP32-S2-WROVER'], 'footprint':'RF_Module:ESP32-S2-WROVER', 'keywords':'RF Radio ESP ESP32 Espressif onboard PCB antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-s2-wroom_esp32-s2-wroom-i_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-S2-WROVER-I\n\nRF Radio ESP ESP32 Espressif onboard PCB antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='IO33',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO34',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO35',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO00',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO36',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO37',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO38',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='IO39',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO40',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO41',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO42',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='RXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO45',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO01',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO46',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO02',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO03',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO04',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO05',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-S3-MINI-1U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-S3-MINI-1U'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-S2-MINI-1', 'RF_Module:ESP32-S2-MINI-1U'], 'footprint':'RF_Module:ESP32-S2-MINI-1', 'keywords':'RF Radio BT ESP ESP32-S3 Espressif', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-s3-mini-1_mini-1u_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-S3-MINI-1U\n\nRF Radio BT ESP ESP32-S3 Espressif', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO11',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO20',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO47',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO33',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO34',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='IO48',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO35',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO36',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='IO37',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO38',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO39',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO40',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO41',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO42',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO45',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='IO46',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-WROOM-32D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-WROOM-32D'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-WROOM-32', 'RF_Module:ESP32-WROOM-32D'], 'footprint':'RF_Module:ESP32-WROOM-32', 'keywords':'RF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-wroom-32d_esp32-wroom-32u_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-WROOM-32D\n\nRF Radio BT ESP ESP32 Espressif onboard PCB antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO25',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SHD/SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SWP/SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCS/CMD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SCK/CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SDO/SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SDI/SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RXD0/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TXD0/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO22',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO23',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SENSOR_VP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSOR_VN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO34',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO35',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO32',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO33',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-WROOM-32UE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-WROOM-32UE'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-WROOM-32D', 'RF_Module:ESP32-WROOM-32UE'], 'footprint':'RF_Module:ESP32-WROOM-32D', 'keywords':'RF Radio BT ESP ESP32 Espressif external U.FL antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-wroom-32e_esp32-wroom-32ue_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-WROOM-32UE\n\nRF Radio BT ESP ESP32 Espressif external U.FL antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO25',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO16',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RXD0/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TXD0/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO22',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO23',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SENSOR_VP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSOR_VN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO34',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO35',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO32',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO33',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP32-WROOM-32UE-R2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP32-WROOM-32UE-R2'}), 'ref_prefix':'U', 'fplist':['RF_Module:ESP32-WROOM-32D', 'RF_Module:ESP32-WROOM-32UE'], 'footprint':'RF_Module:ESP32-WROOM-32D', 'keywords':'RF Radio BT ESP ESP32 Espressif external U.FL antenna', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp32-wroom-32e_esp32-wroom-32ue_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nESP32-WROOM-32UE-R2\n\nRF Radio BT ESP ESP32 Espressif external U.FL antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO25',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='IO17',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO19',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='IO21',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RXD0/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TXD0/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO22',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO23',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SENSOR_VP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSOR_VN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO34',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO35',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO32',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO33',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDBT50Q-P1MV2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDBT50Q-P1MV2'}), 'ref_prefix':'U', 'fplist':['RF_Module:Raytac_MDBT50Q', 'RF_Module:Raytac_MDBT50Q'], 'footprint':'RF_Module:Raytac_MDBT50Q', 'keywords':'BLE ANT ZigBee Thread 802.15.4 nRF52840 nordic MDBT50Q', 'description':'', 'datasheet':'https://www.raytac.com/download/index.php?index_id=43', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMDBT50Q-P1MV2\n\nBLE ANT ZigBee Thread 802.15.4 nRF52840 nordic MDBT50Q', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.00',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P0.01',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1.08',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P1.09',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.10',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDH',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='DCCH',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.11',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P1.00',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.12',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P1.02',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P1.04',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P1.06',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P1.07',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.05',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.03',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.01',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1.14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P1.15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDBT50Q-P512K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDBT50Q-P512K'}), 'ref_prefix':'U', 'fplist':['RF_Module:Raytac_MDBT50Q', 'RF_Module:Raytac_MDBT50Q'], 'footprint':'RF_Module:Raytac_MDBT50Q', 'keywords':'MCU, ARM, BLE, ANT, 2.4GHz, 802.15.4 MDBT50Q', 'description':'', 'datasheet':'https://www.raytac.com/download/index.php?index_id=46', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMDBT50Q-P512K\n\nMCU, ARM, BLE, ANT, 2.4GHz, 802.15.4 MDBT50Q', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.00',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P0.01',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1.08',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P1.09',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDH',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.19',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P1.00',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P1.02',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P1.04',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P1.06',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P1.07',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='P1.05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='P1.01',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1.03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDBT50Q-U1MV2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDBT50Q-U1MV2'}), 'ref_prefix':'U', 'fplist':['RF_Module:Raytac_MDBT50Q', 'RF_Module:Raytac_MDBT50Q', 'RF_Module:Raytac_MDBT50Q'], 'footprint':'RF_Module:Raytac_MDBT50Q', 'keywords':'BLE ANT ZigBee Thread 802.15.4 nRF52840 nordic MDBT50Q', 'description':'', 'datasheet':'https://www.raytac.com/download/index.php?index_id=43', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMDBT50Q-U1MV2\n\nBLE ANT ZigBee Thread 802.15.4 nRF52840 nordic MDBT50Q', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.00',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P0.01',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1.08',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P1.09',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.10',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDH',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='DCCH',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.11',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P1.00',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.12',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P1.02',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P1.04',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P1.06',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P1.07',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P1.05',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P1.03',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P1.01',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1.14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P1.15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDBT50Q-U512K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDBT50Q-U512K'}), 'ref_prefix':'U', 'fplist':['RF_Module:Raytac_MDBT50Q', 'RF_Module:Raytac_MDBT50Q', 'RF_Module:Raytac_MDBT50Q'], 'footprint':'RF_Module:Raytac_MDBT50Q', 'keywords':'MCU, ARM, BLE, ANT, 2.4GHz, 802.15.4 MDBT50Q', 'description':'', 'datasheet':'https://www.raytac.com/download/index.php?index_id=46', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nMDBT50Q-U512K\n\nMCU, ARM, BLE, ANT, 2.4GHz, 802.15.4 MDBT50Q', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0.02',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P0.31',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P0.27',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.00',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P0.01',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P0.26',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P0.04',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.05',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.06',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P0.07',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P0.08',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P1.08',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P1.09',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P0.25',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDH',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P0.19',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P1.00',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0.24',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P1.02',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P0.09',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P1.04',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P1.06',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P1.07',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='P1.05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='P1.01',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P1.03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.03',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-HF-AS923', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-HF-AS923'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811', 'RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-HF-AS923\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PB3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB8',func=pin_types.BIDIR),
            Pin(num='19',name='PB9',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PA8',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PB4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-HF-AU915', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-HF-AU915'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-HF-AU915\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PB3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB8',func=pin_types.BIDIR),
            Pin(num='19',name='PB9',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PA8',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PB4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-HF-IN865', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-HF-IN865'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-HF-IN865\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PB3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB8',func=pin_types.BIDIR),
            Pin(num='19',name='PB9',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PA8',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PB4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-HF-KR920', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-HF-KR920'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-HF-KR920\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PB3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB8',func=pin_types.BIDIR),
            Pin(num='19',name='PB9',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PA8',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PB4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-HF-US915', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-HF-US915'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811', 'RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-HF-US915\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PB3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB8',func=pin_types.BIDIR),
            Pin(num='19',name='PB9',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PA8',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PB4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RAK811-LF-CN470', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAK811-LF-CN470'}), 'ref_prefix':'U', 'fplist':['RF_Module:RAK811', 'RF_Module:RAK811'], 'footprint':'RF_Module:RAK811', 'keywords':'IoT LoRa LoRaWAN RF', 'description':'', 'datasheet':'https://downloads.rakwireless.com/LoRa/RAK811/Hardware_Specification/RAK811_LoRa_Module_Datasheet_V1.4.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRAK811-LF-CN470\n\nIoT LoRa LoRaWAN RF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='PA13',func=pin_types.BIDIR),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='GND',func=pin_types.PASSIVE),
            Pin(num='13',name='PA14',func=pin_types.BIDIR),
            Pin(num='14',name='PA15',func=pin_types.BIDIR),
            Pin(num='15',name='PA3',func=pin_types.BIDIR),
            Pin(num='16',name='PB5',func=pin_types.BIDIR),
            Pin(num='17',name='BOOT0',func=pin_types.INPUT),
            Pin(num='18',name='PB6',func=pin_types.BIDIR),
            Pin(num='19',name='PB7',func=pin_types.BIDIR),
            Pin(num='2',name='PB12',func=pin_types.BIDIR),
            Pin(num='20',name='PA2',func=pin_types.BIDIR),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='22',name='PA1',func=pin_types.BIDIR),
            Pin(num='23',name='PA0',func=pin_types.BIDIR),
            Pin(num='24',name='~{RST}',func=pin_types.INPUT),
            Pin(num='25',name='PB10',func=pin_types.BIDIR),
            Pin(num='26',name='PB11',func=pin_types.BIDIR),
            Pin(num='27',name='PB2',func=pin_types.BIDIR),
            Pin(num='28',name='GND',func=pin_types.PASSIVE),
            Pin(num='29',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='PB14',func=pin_types.BIDIR),
            Pin(num='30',name='GND',func=pin_types.PASSIVE),
            Pin(num='31',name='GND',func=pin_types.PASSIVE),
            Pin(num='32',name='GND',func=pin_types.PASSIVE),
            Pin(num='33',name='RF_OUT',func=pin_types.PASSIVE),
            Pin(num='34',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='PB15',func=pin_types.BIDIR),
            Pin(num='5',name='PB13',func=pin_types.BIDIR),
            Pin(num='6',name='PA9/USART1_TX',func=pin_types.BIDIR),
            Pin(num='7',name='PA10/USART1_RX',func=pin_types.BIDIR),
            Pin(num='8',name='PA12',func=pin_types.BIDIR),
            Pin(num='9',name='PA11',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM69HCW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM69HCW'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'low power Radio ISM Transceiver Module AES encryption SPI HopeRF', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcb8284d838.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM69HCW\n\nlow power Radio ISM Transceiver Module AES encryption SPI HopeRF', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM69W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM69W'}), 'ref_prefix':'U', 'fplist':['RF_Module:HOPERF_RFM69HW', 'RF_Module:HOPERF_RFM69HW'], 'footprint':'RF_Module:HOPERF_RFM69HW', 'keywords':'Radio, ISM, Transceiver, Module, AES', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcbe34756e1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM69W\n\nRadio, ISM, Transceiver, Module, AES', 'pins':[
            Pin(num='1',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ANA',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM95W-915S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM95W-915S2'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcbea20e9ef.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM95W-915S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM96W-315S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM96W-315S2'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcc0ac60235.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM96W-315S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM96W-433S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM96W-433S2'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcc0ac60235.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM96W-433S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM97W-868S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM97W-868S2'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcbea20e9ef.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM97W-868S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM97W-915S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM97W-915S2'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcbea20e9ef.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM97W-915S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM98W-315S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM98W-315S2'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcdb5e17543.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM98W-315S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFM98W-433S2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFM98W-433S2'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Low power long range transceiver module', 'description':'', 'datasheet':'https://www.hoperf.com/data/upload/portal/20181127/5bfcdb5e17543.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nRFM98W-433S2\n\nLow power long range transceiver module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NSS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ANT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TR-52DAT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR-52DAT'}), 'ref_prefix':'U', 'fplist':['RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01'], 'footprint':'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'keywords':'IQRF common transceiver, PCB antenna, thermometer, FSK modulation', 'description':'', 'datasheet':'https://iqrf.org/weben/downloads.php?id=213', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nTR-52DAT\n\nIQRF common transceiver, PCB antenna, thermometer, FSK modulation', 'pins':[
            Pin(num='C1',name='RA0/AN0/C12IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RC2/VOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='RA5/RB4/RC6/AN4/AN11/TX/~{SS}/C2OUT/CCP3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='RC5/RC7/RX/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TR-72DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR-72DA'}), 'ref_prefix':'U', 'fplist':['RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01'], 'footprint':'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'keywords':'IQRF transceiver, PCB antenna, GMSK modulation', 'description':'', 'datasheet':'https://iqrf.org/weben/downloads.php?id=337', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nTR-72DA\n\nIQRF transceiver, PCB antenna, GMSK modulation', 'pins':[
            Pin(num='C1',name='RA0/AN0/C12IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RC2/VOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='RA5/RB4/RC6/AN4/AN11/TX/~{SS}/C2OUT/CCP3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='RC5/RC7/RX/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TR-72DAT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR-72DAT'}), 'ref_prefix':'U', 'fplist':['RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'RF_Module:IQRF_TRx2DA_KON-SIM-01'], 'footprint':'RF_Module:IQRF_TRx2DA_KON-SIM-01', 'keywords':'IQRF transceiver, PCB antenna, thermometer, GMSK modulation', 'description':'', 'datasheet':'https://iqrf.org/weben/downloads.php?id=337', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\nTR-72DAT\n\nIQRF transceiver, PCB antenna, thermometer, GMSK modulation', 'pins':[
            Pin(num='C1',name='RA0/AN0/C12IN0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RC2/VOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='RA5/RB4/RC6/AN4/AN11/TX/~{SS}/C2OUT/CCP3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='RC3/SCK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='RC4/SDI/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='RC5/RC7/RX/SDO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'iM880B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'iM880B'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'IOT LoRa', 'description':'', 'datasheet':'http://www.wireless-solutions.de/images/stories/downloads/Radio%20Modules/iM880B/General_Information/iM880B_Datasheet_V1_0.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Module.kicad_sym\niM880B\n\nIOT LoRa', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P7-IO/SPI-MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P8-IO/SPI-MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P9-IO/SPI-CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P10-IO/SPI-NSS',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='RxD-IO/UART-RX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TxD-IO/UART-TX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1-IO/JTCK/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P11-IO',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P12-IO/I2C-SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='P13-IO/I2C-SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P14-IO/ADC',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P15-IO/WKUP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='BOOT',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='P17-IO/ADC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2-IO/JTMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='RF',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P3-IO/JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P4-IO/JTDI',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P5-IO/UART-CTS',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P6-IO/UART-RTS',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])